@@ -8,12 +8,12 @@ use x11::{
   },
 };
 
-pub fn get_display_infos() -> Result<Vec<DisplayInfo>, i32> {
+pub fn get_display_infos() -> Vec<DisplayInfo> {
   unsafe {
     let display_ptr = XOpenDisplay(ptr::null_mut());
 
     if display_ptr.is_null() {
-      return Err(-1);
+      return vec![];
     }
 
     let window_id = XDefaultRootWindow(display_ptr);
@@ -63,11 +63,11 @@ pub fn get_display_infos() -> Result<Vec<DisplayInfo>, i32> {
     XRRFreeScreenResources(xrr_screen_resources_ptr);
     XCloseDisplay(display_ptr);
 
-    Ok(display_infos)
+    display_infos
   }
 }
 
-pub fn get_display_info_from_point(x: i32, y: i32) -> Result<DisplayInfo, i32> {
+pub fn get_display_info_from_point(x: i32, y: i32) -> Option<DisplayInfo> {
   match get_display_infos() {
     Ok(display_infos) => {
       for display_info in display_infos {
@@ -76,12 +76,12 @@ pub fn get_display_info_from_point(x: i32, y: i32) -> Result<DisplayInfo, i32> {
           && y >= display_info.y
           && y <= display_info.y + display_info.height as i32
         {
-          return Ok(display_info);
+          return Some(display_info);
         }
       }
 
-      Err(-1)
+      None
     }
-    Err(i) => Err(i),
+    Err(_) => None,
   }
 }
